# Global Variables

def init():

    global SA_CONTAINER_NAME
    global SA_CONNECTION_STRING
    global COMMON_ROLE_NAME
    global DATABASE_TYPE
    global DB_NAME
    global DB_USER
    global DB_PASS
    global DB_HOST
    global DB_SSL_CA
    global ADMIN_PASSWORD

    SA_CONTAINER_NAME = ""
    SA_CONNECTION_STRING = ""
    COMMON_ROLE_NAME = ""
    DATABASE_TYPE = ""
    DB_NAME = ""
    DB_USER = ""
    DB_PASS = ""
    DB_HOST = ""
    DB_SSL_CA = ""
    ADMIN_PASSWORD = ""
